<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Última comprobación:</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Si sale del programa beta, no recibirá más actualizaciones beta</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>Ver registro de actualizaciones</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Historial de actualizaciones</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Sin historial de actualizaciones</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Actualizaciones del sistema</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Actualizaciones de seguridad</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Ofrece una actualización acumulativa que incluye nuevas funciones, actualizaciones de calidad y seguridad</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Ofrece actualizaciones de seguridad</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Fecha de instalación:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Ver detalles</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Hora de lanzamiento:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>Registro de actualizaciones</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>Exportar al escritorio</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>NINGUNA</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>BAJA</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>MEDIA</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>ALTA</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>CRÍTICA</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>riesgo crítico</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>alto riesgo</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>riesgo medio</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>riesgo bajo</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconocido</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Esta actualización corrige</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>vulnerabilidades</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>vulnerabilidad</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 de %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>Para más detalles, visite</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Comprobando actualizaciones, espere…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Su sistema está actualizado</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconocido</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>La descarga de actualizaciones falló. Primero libere %1 de espacio en disco.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Error de dependencias, no se encontraron actualizaciones.</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Compruebe su red e inténtelo de nuevo.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>La descarga de actualizaciones falló. Compruebe su red e inténtelo de nuevo.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>No se puede realizar la copia de seguridad del sistema. Si continúa con las actualizaciones, no podrá volver al sistema anterior más adelante.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Si continúa con las actualizaciones, no podrá volver al sistema anterior más adelante.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Espacio de disco insuficiente</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Error DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Archivo faltante</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>La conexión del servicio es anormal, verifique la red e inténtelo nuevamente</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>La configuración del repositorio no es válida, verifíquela e inténtelo nuevamente.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Buscar de nuevo</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Política de privacidad</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Para utilizar este software, debe aceptar la %1 que acompaña a las actualizaciones de software.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Activa los interruptores en Actualizar contenido para obtener mejores experiencias</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Su sistema no está activado y no ha podido conectarse a los servicios de actualización</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Las actualizaciones del sistema están desactivadas. Póngase en contacto con su administrador para obtener ayuda.</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>El sistema tiene activada la función de recuperación automática y no admite actualizaciones. Si tiene alguna pregunta, póngase en contacto con el administrador de la empresa.</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>Ya se han descargado las actualizaciones. ¿Qué quiere hacer?</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>Instalación silenciosa</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Actualizar y reiniciar</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Actualizar y apagar</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Intercambio de espejo inteligente</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Tipo de actualización</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Actualización de funciones</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Ofrece una actualización acumulativa que incluye nuevas funciones, actualizaciones de calidad y seguridad</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Actualizaciones de seguridad</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Ofrece actualizaciones de seguridad</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Actualizaciones de terceros</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Ofrece actualizaciones de repositorios adicionales</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Limitar velocidad</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Ajuste de límites</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Descarga automática</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Al activar la descarga automática de actualizaciones, se descargarán automáticamente cuando esté conectado a Internet</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Descargar cuando está inactivo</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Finaliza</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Ajustes avanzados</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Notificación de actualizaciones</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Borrar caché de paquetes</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Historial de actualizaciones</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Unirse al canal de pruebas internas (versión inestable)</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Haga clic aquí para completar la solicitud</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandir</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation>Los usuarios del foro de nivel 2 o superior pueden unirse a la prueba beta para recibir las últimas actualizaciones.</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>Sólo se admiten números entre 1-99999</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Actualizaciones del sistema</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Se corrigieron algunos errores conocidos y vulnerabilidades de seguridad.</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Actualizaciones de seguridad</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Repositorios de terceros</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>registro de actualizaciones</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Error al exportar el registro, intentelo de nuevo</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>El registro se exportó al escritorio</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Conéctelo y luego instale las actualizaciones.</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Actualización del sistema</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Actualización y mejora del sistema</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Ajustes de actualización</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Descarga de actualización completada</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Instalar actualizaciones</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Tamaño de la actualización: </translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>La descarga de la actualización falló</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Descargando actualizaciones...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Ajustes de actualizaciones, actualizaciones de seguridad, descarga automática y notificación</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Reiniciar ahora</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Instalando actualizaciones...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Reintentar</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Continuar actualización</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Actualizaciones disponibles</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>La instalación de la actualización falló</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Para garantizar el correcto funcionamiento del sistema y las aplicaciones, reinicie el equipo después de la actualización</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Copia de seguridad en progreso...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Copia de seguridad en progreso </translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>La copia de seguridad falló</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Actualización exitosa</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Si continúa con las actualizaciones, no podrá volver al sistema anterior más adelante.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Vuelva a intentar</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Proceder a la actualización</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>La capacidad de la batería es inferior al 60%. Para obtener actualizaciones exitosas, conéctese.</translation>
    </message>
</context>
</TS>